@@ -22,13 +22,13 @@
 #include "appearance.h"
 #include "gnome-wp-info.h"
 #include "gnome-wp-item.h"
-#include "gnome-wp-utils.h"
 #include "gnome-wp-xml.h"
 #include "wp-cellrenderer.h"
 #include <glib/gi18n.h>
 #include <string.h>
 #include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-thumbnail.h>
+#define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnomeui/gnome-bg.h>
 
 typedef enum {
@@ -131,14 +131,16 @@ static void on_item_changed (GnomeBG *bg, AppearanceData *data) {
 
   if (!item)
     return;
-  
+
   model = gtk_tree_row_reference_get_model (item->rowref);
   path = gtk_tree_row_reference_get_path (item->rowref);
 
   if (gtk_tree_model_get_iter (model, &iter, path)) {
+    GdkPixbuf *pixbuf;
+
     g_signal_handlers_block_by_func (bg, G_CALLBACK (on_item_changed), data);
-      
-    GdkPixbuf *pixbuf = gnome_wp_item_get_thumbnail (item, data->thumb_factory);
+
+    pixbuf = gnome_wp_item_get_thumbnail (item, data->thumb_factory);
     if (pixbuf) {
       gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
                           0, pixbuf,
@@ -272,31 +274,21 @@ wp_option_menu_set (AppearanceData *data,
   }
   else
   {
+    gint style;
+
     if (!strcmp (value, "centered"))
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
-                                GNOME_WP_SCALE_TYPE_CENTERED);
-    }
+      style = GNOME_WP_SCALE_TYPE_CENTERED;
     else if (!strcmp (value, "stretched"))
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
-                                GNOME_WP_SCALE_TYPE_STRETCHED);
-    }
+      style = GNOME_WP_SCALE_TYPE_STRETCHED;
     else if (!strcmp (value, "scaled"))
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
-                                GNOME_WP_SCALE_TYPE_SCALED);
-    }
+      style = GNOME_WP_SCALE_TYPE_SCALED;
     else if (!strcmp (value, "zoom"))
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
-                                GNOME_WP_SCALE_TYPE_ZOOM);
-    }
-    else if (!strcmp (value, "none"))
-    {
-      gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
-                                GNOME_WP_SCALE_TYPE_TILED);
-    }
+      style = GNOME_WP_SCALE_TYPE_ZOOM;
+    else
+      style = GNOME_WP_SCALE_TYPE_TILED;
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (data->wp_style_menu),
+                              style);
   }
 }
 
@@ -383,7 +375,8 @@ wp_scale_type_changed (GtkComboBox *combobox,
   if (pixbuf != NULL)
     g_object_unref (pixbuf);
 
-  gconf_client_set_string (data->client, WP_OPTIONS_KEY, item->options, NULL);
+  if (gconf_client_key_is_writable (data->client, WP_OPTIONS_KEY, NULL))
+    gconf_client_set_string (data->client, WP_OPTIONS_KEY, item->options, NULL);
 }
 
 static void
@@ -425,8 +418,9 @@ wp_shade_type_changed (GtkWidget *combobox,
   if (pixbuf != NULL)
     g_object_unref (pixbuf);
 
-  gconf_client_set_string (data->client, WP_SHADING_KEY,
-                           item->shade_type, NULL);
+  if (gconf_client_key_is_writable (data->client, WP_SHADING_KEY, NULL))
+    gconf_client_set_string (data->client, WP_SHADING_KEY,
+                             item->shade_type, NULL);
 }
 
 static void
@@ -874,8 +868,8 @@ static gboolean
 wp_load_stuffs (void *user_data)
 {
   AppearanceData *data;
-  gchar * imagepath, * style, * uri;
-  GnomeWPItem * item;
+  gchar *imagepath, *style, *uri;
+  GnomeWPItem *item;
 
   data = (AppearanceData *) user_data;
 
@@ -883,8 +877,6 @@ wp_load_stuffs (void *user_data)
   g_hash_table_foreach (data->wp_hash, (GHFunc) wp_props_load_wallpaper,
                         data);
 
-  /*gdk_window_set_cursor (data->window->window, NULL);*/
-
   style = gconf_client_get_string (data->client,
                                    WP_OPTIONS_KEY,
                                    NULL);
@@ -906,22 +898,21 @@ wp_load_stuffs (void *user_data)
 
   item = g_hash_table_lookup (data->wp_hash, imagepath);
 
-  if (item != NULL && strcmp (style, "none") != 0)
+  if (item != NULL)
   {
-    if (item->deleted == TRUE)
+    /* update with the current gconf settings */
+    gnome_wp_item_update (item);
+
+    if (strcmp (style, "none") != 0)
     {
-      item->deleted = FALSE;
-      wp_props_load_wallpaper (item->filename, item, data);
+      if (item->deleted == TRUE)
+      {
+        item->deleted = FALSE;
+        wp_props_load_wallpaper (item->filename, item, data);
+      }
+
+      select_item (data, item, FALSE);
     }
-
-    select_item (data, item, FALSE);
-
-    wp_option_menu_set (data, item->options, FALSE);
-    wp_option_menu_set (data, item->shade_type, TRUE);
-
-    gtk_color_button_set_color (GTK_COLOR_BUTTON (data->wp_pcpicker), item->pcolor);
-    gtk_color_button_set_color (GTK_COLOR_BUTTON (data->wp_scpicker), item->scolor);
-
   }
   else if (strcmp (style, "none") != 0)
   {
